@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: html.c,v 1.115 2005/03/08 14:38:28 hany Exp $
+ * $Id: html.c,v 1.116 2005/04/29 20:27:32 hany Exp $
  */
 
 #include <config.h>
@@ -1107,9 +1107,6 @@ void generateLinks(FILE *html, int installed) {
             rpm2html_url, localizedStrings[LANG_BYNAME_HTML],
 	    localizedStrings[LANG_SORTED_BY_NAME]);
 
-    fprintf(html, "<td><a href=\"http://rpmfind.net/linux/rpm2html/mirrors.html\">%s</a></td>\n",
-	    localizedStrings[LANG_MIRRORS]);
-
     for (i = 0;i < rpm2html_nb_extra_headers;i++) {
         if ((*rpm2html_headers_url[i] == '/') ||
 	    (!strncmp(rpm2html_headers_url[i], "http://", 7)) ||
