@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmopen.c,v 1.112 2005/03/16 20:13:10 hany Exp $
+ * $Id: rpmopen.c,v 1.114 2005/04/29 20:58:33 hany Exp $
  */
 
 #include <config.h>
@@ -186,7 +186,7 @@ checkReleaseName(const char *res)
             res++;
         else
             return (0);
-        if ((res - base) > 20)
+        if ((res - base) > 65)
             return (0);
     }
     return (1);
@@ -691,6 +691,20 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
             res += len;
             cp = holdp[i];
             pos = 0;
+
+            if ((res - buffer + strlen(holdp[i])) > buffer_size) {
+                int delta = res - buffer;
+
+                buffer_size *= 2;
+                buffer = (char *) xmlRealloc(buffer, buffer_size);
+                if (buffer == NULL) {
+                    fprintf(stderr, "cannot re-allocate %d bytes: %s\n",
+                            buffer_size, strerror(errno));
+                    exit(1);
+                }
+                res = &buffer[delta];
+            }
+
             while (*cp) {
                 if (pos++ == 0) {
                     *res++ = ' ';
